@@ -318,7 +318,7 @@ rb_iradio_source_constructor (GType type, guint n_construct_properties,
 						    FALSE, FALSE);
 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_TITLE);
 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_GENRE);
-	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_QUALITY);
+/* 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_QUALITY); */
 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_RATING);
 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_PLAY_COUNT);
 	rb_entry_view_append_column (source->priv->stations, RB_ENTRY_VIEW_COL_LAST_PLAYED);
@@ -437,6 +437,19 @@ rb_iradio_source_add_station (RBIRadioSource *source,
 	RhythmDBEntry *entry;
 	GValue val = { 0, };
 
+	if (uri && !g_utf8_validate (uri, -1, NULL)) {
+		rb_debug ("uri \"%s\" is not valid UTF-8", uri);
+		return;
+	}
+	if (title && !g_utf8_validate (title, -1, NULL)) {
+		rb_debug ("title \"s\" is not valid UTF-8", title);
+		return;
+	}
+	if (genre && !g_utf8_validate (genre, -1, NULL)) {
+		rb_debug ("genre \"s\" is not valid UTF-8", genre);
+		genre = "";
+	}
+
 	rhythmdb_write_lock (source->priv->db);
 
 	entry = rhythmdb_entry_lookup_by_location (source->priv->db, uri);
